@@ -1,8 +1,8 @@
-from .commands import TairCommands
-
 import redis.client
 import redis.cluster
 
+from tair.commands import TairCommands
+
 
 class Pipeline(redis.client.Pipeline, TairCommands):
     def __init__(
